@@ -58,6 +58,7 @@ private:
   cuid_t cuid_;
   std::unique_ptr<HttpRequest> httpRequest_;
   std::unique_ptr<HttpHeader> httpHeader_;
+
 public:
   HttpResponse();
 
@@ -69,7 +70,7 @@ public:
    * this function returns the filename from it.
    * If it is not there, returns the part of filename from the request URL.
    */
-  std::string determinFilename() const;
+  std::string determineFilename() const;
 
   void retrieveCookie();
 
@@ -114,25 +115,20 @@ public:
     return httpRequest_;
   }
 
-  void setCuid(cuid_t cuid)
-  {
-    cuid_ = cuid;
-  }
+  void setCuid(cuid_t cuid) { cuid_ = cuid; }
 
   Time getLastModifiedTime() const;
 
   bool supportsPersistentConnection() const;
 
-  void getMetalinKHttpEntries
-  (std::vector<MetalinkHttpEntry>& result,
-   const std::shared_ptr<Option>& option) const;
-#ifdef ENABLE_MESSAGE_DIGEST
+  void getMetalinKHttpEntries(std::vector<MetalinkHttpEntry>& result,
+                              const std::shared_ptr<Option>& option) const;
+
   // Returns all digests specified in Digest header field.  Sort
   // strong algorithm first. Strength is defined in MessageDigest. If
   // several same digest algorithms are available, but they have
   // different value, they are all ignored.
   void getDigest(std::vector<Checksum>& result) const;
-#endif // ENABLE_MESSAGE_DIGEST
 };
 
 } // namespace aria2
