@@ -76,10 +76,9 @@ void BtBitfieldMessageTest::testCreateMessage()
   unsigned char data[5 + 2];
   bittorrent::createPeerMessageString(data, sizeof(data), 3, 5);
   memcpy(&data[5], bitfield, sizeof(bitfield));
-  unsigned char* rawmsg = msg.createMessage();
-  CPPUNIT_ASSERT(memcmp(rawmsg, data, 7) == 0);
-  delete[] rawmsg;
-  CPPUNIT_ASSERT_EQUAL((size_t)7, msg.getMessageLength());
+  auto rawmsg = msg.createMessage();
+  CPPUNIT_ASSERT_EQUAL((size_t)7, rawmsg.size());
+  CPPUNIT_ASSERT(std::equal(std::begin(rawmsg), std::end(rawmsg), data));
 }
 
 void BtBitfieldMessageTest::testDoReceivedAction()
